pandoc: A document converter
============================

Description
-----------

This dummy package represents the document converter pandoc.

We do not have an SPKG for it. The purpose of this dummy package is to
associate system package lists with it.
